==> kadu_0.6.5.1.orig.tar.gz: globalhotkeys/translations/globalhotkeys_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="pl">
<context>
	<name>@default</name>

	<message>
		<location filename="" line="0"/>
		<source>Kadu - Global hotkeys</source>
		<translation>Kadu - Skróty globalne</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Hotkey %% is used by another application.</source>
		<translation>Skrót %% jest używany przez inną aplikację.</translation>
	</message>

	<message>
		<location filename="" line="0"/>
		<source>Shortcuts</source>
		<translation>Skróty</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Global hotkeys</source>
		<translation>Skróty globalne</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Show Kadu's main window</source>
		<translation>Pokaż główne okno Kadu</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Hide Kadu's main window</source>
		<translation>Ukryj główne okno Kadu</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Show/hide Kadu's main window</source>
		<translation>Pokaż/ukryj główne okno Kadu</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Chats</source>
		<translation>Rozmowy</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Contacts</source>
		<translation>Kontakty</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Open incoming chat window</source>
		<translation>Otwórz okno rozmowy przychodzącej</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Open all incoming chat windows</source>
		<translation>Otwórz okna wszystkich rozmów przychodzących</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Minimize all opened chat windows</source>
		<translation>Zminimalizuj wszystkie otwarte okna rozmów</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Restore all minimized chat windows</source>
		<translation>Przywróć wszystkie zminimalizowane okna rozmów</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Minimize/restore all chat windows</source>
		<translation>Zminimalizuj/przywróć wszystkie okna rozmów</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Close all chat windows</source>
		<translation>Zamknij wszystkie okna rozmów</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Open chat with ...</source>
		<translation>Rozpocznij rozmowę z ...</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Open recent chats ...</source>
		<translation>Ostatnie rozmowy ...</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Add new shortcut ...</source>
		<translation>Dodaj nowy skrót ...</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Contacts (comma separated)</source>
		<translation>Kontakty (rozdzielone przecinkami)</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Shortcut</source>
		<translation>Skrót</translation>
	</message>

	<message>
		<location filename="" line="0"/>
		<source>no recent chats</source>
		<translation>brak ostatnich rozmów</translation>
	</message>



</context>
</TS>

==> kadu_0.6.5.3.orig.tar.gz: globalhotkeys/translations/globalhotkeys_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="pl">
<context>
	<name>@default</name>

	<message>
		<location filename="" line="0"/>
		<source>Shortcuts</source>
		<translation>Skróty</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Global hotkeys</source>
		<translation>Skróty globalne</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Show Kadu's main window</source>
		<translation>Pokaż główne okno Kadu</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Hide Kadu's main window</source>
		<translation>Ukryj główne okno Kadu</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Change description</source>
		<translation>Zmień opis</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Show/hide Kadu's main window</source>
		<translation>Pokaż/ukryj główne okno Kadu</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Chats</source>
		<translation>Rozmowy</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Contacts</source>
		<translation>Kontakty</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Contacts menus</source>
		<translation>Menu kontaktów</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Open incoming chat window</source>
		<translation>Otwórz okno rozmowy przychodzącej</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Open all incoming chat windows</source>
		<translation>Otwórz okna wszystkich rozmów przychodzących</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Minimize all opened chat windows</source>
		<translation>Zminimalizuj wszystkie otwarte okna rozmów</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Restore all minimized chat windows</source>
		<translation>Przywróć wszystkie zminimalizowane okna rozmów</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Minimize/restore all chat windows</source>
		<translation>Zminimalizuj/przywróć wszystkie okna rozmów</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Close all chat windows</source>
		<translation>Zamknij wszystkie okna rozmów</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Open chat with ...</source>
		<translation>Rozpocznij rozmowę z ...</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Open recent chats ...</source>
		<translation>Ostatnie rozmowy ...</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Shortcut</source>
		<translation>Skrót</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Add new shortcut ...</source>
		<translation>Dodaj nowy skrót ...</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Contacts (comma separated)</source>
		<translation>Kontakty (rozdzielone przecinkami)</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Add new contacts menu ...</source>
		<translation>Dodaj nowe menu kontaktów ...</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Include current chats</source>
		<translation>Dołącz aktualne rozmowy</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Include chats with pending messages</source>
		<translation>Dołącz rozmowy z nieodebranymi wiadomościami</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Include recent chats</source>
		<translation>Dołącz ostatnie rozmowy</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Include online contacts</source>
		<translation>Dołącz dostępne kontakty</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>only from these groups (comma separated)</source>
		<translation>tylko z tych grup (rozdzielone przecinkami)</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>leave empty to disable this filter</source>
		<translation>pozostaw to pole puste, aby wyłączyć ten filtr</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Treat contacts blocking me as online</source>
		<translation>Traktuj kontakty, które mnie blokują jako dostępne</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Include these contacts (comma separated)</source>
		<translation>Dołącz te kontakty (rozdzielone przecinkami)</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Include contacts from these gropus (comma separated)</source>
		<translation>Dołącz te grupy (rozdzielone przecinkami)</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Exclude these contacts (comma separated)</source>
		<translation>Pomiń te kontakty (rozdzielone przecinkami)</translation>
	</message>


	<message>
		<location filename="" line="0"/>
		<source>Kadu - Global hotkeys</source>
		<translation>Kadu - Skróty globalne</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>Hotkey %% is used by another application.</source>
		<translation>Skrót %% jest używany przez inną aplikację.</translation>
	</message>
	<message>
		<location filename="" line="0"/>
		<source>no contacts to display</source>
		<translation>brak kontaktów do wyświetlenia</translation>
	</message>




</context>
</TS>
